<?php
/**
 * Canela Theme Config File
 */

if ( ! function_exists( 'canela_options_config' ) ) {

	function canela_options_config( $wp_customize ){

		$canela_before_default_section = 40; // Before Colors.
		
		/*** General Settings section ***/
		$wp_customize->add_section(
			'general_settings',
			array(
				'title'    => esc_html__( 'General Settings', 'canela' ),
				'priority' => ($canela_before_default_section - 8),
			)
		);
	
		// Enable AJAX
		$wp_customize->add_setting(
			'clapat_canela_enable_ajax',
			array(
				'default'           	=> 0,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_enable_ajax',
			array(
				'label'   		=> esc_html__( 'Load Pages With Ajax', 'canela' ),
				'description'  	=> esc_html__( 'When navigates to another page it loads the target content without reloading the current page.', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'checkbox',
			)
		);
		
		// Enable Smooth Scroll
		$wp_customize->add_setting(
			'clapat_canela_enable_smooth_scrolling',
			array(
				'default'           	=> 0,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_enable_smooth_scrolling',
			array(
				'label'   		=> esc_html__( 'Enable Smooth Scrolling', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'checkbox',
			)
		);
		
		// Enable Smooth Drag
		$wp_customize->add_setting(
			'clapat_canela_enable_smooth_drag',
			array(
				'default'           	=> 0,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_enable_smooth_drag',
			array(
				'label'   		=> esc_html__( 'Enable Smooth Dragging', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'checkbox',
			)
		);
		
		// Enable Preloader
		$wp_customize->add_setting(
			'clapat_canela_enable_preloader',
			array(
				'default'           	=> 1,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_enable_preloader',
			array(
				'label'   		=> esc_html__( 'Enable Preloader', 'canela' ),
				'description'  	=> esc_html__( 'Enable preloader mask while the page is loading.', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'checkbox',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_preloader_hover_first_line',
			array(
				'default'           	=> esc_html__( 'Stay', 'canela' ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_preloader_hover_first_line',
			array(
				'label'   		=> esc_html__( 'Preloader Hover Text - First Line', 'canela' ),
				'description'	=> esc_html__( 'First line of the view caption displayed on hover in preloader.', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'text',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_preloader_hover_second_line',
			array(
				'default'           	=> esc_html__( 'Relaxed', 'canela' ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_preloader_hover_second_line',
			array(
				'label'   		=> esc_html__( 'Preloader Hover Text - Second Line', 'canela' ),
				'description'	=> esc_html__( 'Second line of the view caption displayed on hover in preloader.', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'text',
			)
		);
		
		// Enable Fullscreen Menu
		$wp_customize->add_setting(
			'clapat_canela_enable_fullscreen_menu',
			array(
				'default'           	=> 0,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_enable_fullscreen_menu',
			array(
				'label'   		=> esc_html__( 'Enable Fullscreen menu on desktop', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'checkbox',
			)
		);
		
		// Menu button caption
		$wp_customize->add_setting(
			'clapat_canela_menu_btn_caption',
			array(
				'default'           	=> esc_html__( 'Menu', 'canela' ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_menu_btn_caption',
			array(
				'label'   		=> esc_html__( 'Menu button caption', 'canela' ),
				'description'	=> esc_html__( 'Text preceding the burger menu button.', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'text',
			)
		);
		
		// Enable Back To Top button
		$wp_customize->add_setting(
			'clapat_canela_enable_back_to_top',
			array(
				'default'          		=> 1,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_enable_back_to_top',
			array(
				'label'   		=> esc_html__( 'Enable Back To Top Button', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'checkbox',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_back_to_top_caption',
			array(
				'default'          		=> esc_html__( 'Back Top', 'canela' ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_back_to_top_caption',
			array(
				'label'   		=> esc_html__( 'Back To Top Caption', 'canela' ),
				'description'	=> esc_html__( 'Caption displayed next to the back to top button in the footer.', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'text',
			)
		);
		
		// Cursor color
		$wp_customize->add_setting(
			'clapat_canela_regular_cursor_color',
			array(
				'default'           	=> '#f33a3a',
				'sanitize_callback' 	=> 'sanitize_hex_color',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control( 
			$wp_customize, 
			'clapat_canela_regular_cursor_color', 
			array(
				'label'      => esc_html__( 'Cursor Color', 'canela' ),
				'description' => esc_html__('Set the mouse ball cursor color.', 'canela'),
				'section'    => 'header_settings'
			)
		));
		
		// Cursor hover color
		$wp_customize->add_setting(
			'clapat_canela_hover_cursor_color',
			array(
				'default'           	=> '#f33a3a',
				'sanitize_callback' 	=> 'sanitize_hex_color',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control( 
			$wp_customize, 
			'clapat_canela_hover_cursor_color', 
			array(
				'label'      => esc_html__( 'Cursor Hover Color', 'canela' ),
				'description' => esc_html__('Set the mouse ball cursor color on hover.', 'canela'),
				'section'    => 'header_settings'
			)
		));
		
		// Global background page type
		$wp_customize->add_setting(
			'clapat_canela_default_page_bknd_type',
			array(
				'default'           	=> 'light-content',
				'sanitize_callback' 	=> 'canela_sanitize_default_page_bknd_type',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_default_page_bknd_type',
			array(
				'label'   		=> esc_html__('Default Background Type', 'canela'),
				'description'	=> esc_html__('Default background type for pages, posts and category pages. The background type set in page options will overwrite this option.', 'canela'),
				'section' 		=> 'general_settings',
				'type'    		=> 'select',
				'choices'   	=> array( 'dark-content' => esc_html__('White', 'canela'),
										'light-content' => esc_html__('Black', 'canela') ),
			)
		);
		
		// Enable page title as hero caption
		$wp_customize->add_setting(
			'clapat_canela_enable_page_title_as_hero',
			array(
				'default'           	=> 1,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_enable_page_title_as_hero',
			array(
				'label'   		=> esc_html__( 'Display Page Title When Hero Section Is Disabled', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'checkbox',
			)
		);
		
		// Enable Magic Cursor
		$wp_customize->add_setting(
			'clapat_canela_enable_magic_cursor',
			array(
				'default'           	=> 0,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_enable_magic_cursor',
			array(
				'label'   		=> esc_html__( 'Enable Magic Cursor', 'canela' ),
				'section' 		=> 'general_settings',
				'type'    		=> 'checkbox',
			)
		);
		/*** End General Settings section ***/
		
		
		/*** Header Settings section ***/
		$wp_customize->add_section(
			'header_settings',
			array(
				'title'    => esc_html__( 'Header Settings', 'canela' ),
				'priority' => ($canela_before_default_section - 7),
			)
		);
		
		// Logo (default)
		$wp_customize->add_setting(
			'clapat_canela_logo',
			array(
				'default'           		=> get_template_directory_uri() . '/images/logo.png',
				'sanitize_callback' 	=> 'esc_url_raw',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Image_Control( 
			$wp_customize, 
			'clapat_canela_logo', 
			array(
				'label'      => esc_html__( 'Header Logo', 'canela' ),
				'description' => esc_html__('Upload your logo to be displayed at the left side of the header menu.', 'canela'),
				'section'    => 'header_settings'
			)
		));
		
		// Logo (light version)
		$wp_customize->add_setting(
			'clapat_canela_logo_light',
			array(
				'default'           	=> get_template_directory_uri() . '/images/logo-white.png',
				'sanitize_callback' 	=> 'esc_url_raw',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Image_Control( 
			$wp_customize, 
			'clapat_canela_logo_light', 
			array(
				'label'      => esc_html__( 'Header Logo Light', 'canela' ),
				'description' => esc_html__('Light logo displayed on dark backgrounds.', 'canela'),
				'section'    => 'header_settings'
			)
		));
		/*** End Header Settings section ***/
		
		
		/*** Footer Settings section ***/
		$wp_customize->add_section(
			'footer_settings',
			array(
				'title'    => esc_html__( 'Footer Settings', 'canela' ),
				'priority' => ($canela_before_default_section - 6),
			)
		);
		
		// Copyright
		$wp_customize->add_setting(
			'clapat_canela_footer_copyright',
			array(
				'default'           	=> wp_kses( __('2020 Copyright <a target="_blank" href="https://www.clapat.com/themes/canela/">Canela Theme</a>.', 'canela'), 'canela_allowed_html' ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_footer_copyright',
			array(
				'label'   		=> esc_html__( 'Copyright text', 'canela' ),
				'description'	=> esc_html__( 'This is the copyright text displayed in the footer.', 'canela' ),
				'section' 		=> 'footer_settings',
				'type'    		=> 'textarea',
			)
		);
		
		// Social links
		$wp_customize->add_setting(
			'clapat_canela_footer_social_links_prefix',
			array(
				'default'           	=> esc_html__( 'Follow Us', 'canela' ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_footer_social_links_prefix',
			array(
				'label'   		=> esc_html__( 'Social Links Prefix', 'canela' ),
				'description'	=> esc_html__('Text preceding the social links.', 'canela'),
				'section' 		=> 'footer_settings',
				'type'    		=> 'text',
			)
		);
		
		// Social Links Display
		$wp_customize->add_setting(
			'clapat_canela_social_links_icons',
			array(
				'default'           	=> 0,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_social_links_icons',
			array(
				'label'   		=> esc_html__( 'Display Social Links As Fontawesome Icons', 'canela' ),
				'description'  	=> esc_html__( 'If unchecked will display the social networks acronyms.', 'canela' ),
				'section' 		=> 'footer_settings',
				'type'    		=> 'checkbox',
			)
		);
		
		global $canela_social_links;
		$social_network_ids = array_keys( $canela_social_links );
		for( $idx = 1; $idx <= CANELA_MAX_SOCIAL_LINKS; $idx++ ){

			$wp_customize->add_setting(
				'clapat_canela_footer_social_' . $idx,
				array(
					'default'           	=> 'Fb',
					'sanitize_callback' 	=> 'canela_sanitize_social_links',
				)
			);
			
			$wp_customize->add_control(
				'clapat_canela_footer_social_' . $idx,
				array(
					'label'   		=>  esc_html__('Social Network Name ', 'canela' ) . $idx,
					'section' 		=> 'footer_settings',
					'type'    		=> 'select',
					'choices'   	=> $canela_social_links,
				)
			);
			
			$wp_customize->add_setting(
				'clapat_canela_footer_social_url_' . $idx,
				array(
					'default'           	=> '',
					'sanitize_callback' 	=> 'esc_url_raw',
				)
			);
			
			$wp_customize->add_control(
				'clapat_canela_footer_social_url_' . $idx,
				array(
					'label'   		=>  esc_html__('Social Link URL ', 'canela' ) . $idx,
					'section' 		=> 'footer_settings',
					'type'    		=> 'url',
				)
			);
			
		}
		/*** End Footer Settings section ***/
		
		/*** Showcase Settings section ***/
		$wp_customize->add_section(
			'showcase_settings',
			array(
				'title'    => esc_html__( 'Showcase Settings', 'canela' ),
				'priority' => ($canela_before_default_section - 5),
			)
		);
		
		// Showcase transition image
		$wp_customize->add_setting(
			'clapat_canela_showcase_transition_pattern_image',
			array(
				'default'           	=> 'aqua-light',
				'sanitize_callback' 	=> 'canela_sanitize_showcase_transition_pattern_image',
			)
		);
		
		global $canela_slide_transitions_labels;
		$wp_customize->add_control(
			'clapat_canela_showcase_transition_pattern_image',
			array(
				'label'   		=> esc_html__('Showcase Transition Pattern Image', 'canela'),
				'section' 		=> 'showcase_settings',
				'type'    		=> 'select',
				'choices'   	=> $canela_slide_transitions_labels,
			)
		);
		
		// Showcase custom transition image
		$wp_customize->add_setting(
			'clapat_canela_showcase_transition_pattern_custom_image',
			array(
				'default'           	=> '',
				'sanitize_callback' 	=> 'esc_url_raw',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Image_Control( 
			$wp_customize, 
			'clapat_canela_showcase_transition_pattern_custom_image', 
			array(
				'label'      => esc_html__( 'Showcase Transition Pattern Image - Custom', 'canela' ),
				'description' => esc_html__('Upload your custom showcase transition pattern image.', 'canela'),
				'section'    => 'showcase_settings'
			)
		));
		/*** End Showcase Settings section ***/
		
		/*** Portfolio Settings section ***/
		$wp_customize->add_section(
			'portfolio_settings',
			array(
				'title'    => esc_html__( 'Portfolio Settings', 'canela' ),
				'priority' => ($canela_before_default_section - 4),
			)
		);
		
		// Custom portfolio slug
		$wp_customize->add_setting(
			'clapat_canela_portfolio_custom_slug',
			array(
				'default'           	=> '',
				'sanitize_callback' 	=> 'canela_sanitize_slug_field',
				'transport'         	=> 'postMessage',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_custom_slug',
			array(
				'label'   		=> esc_html__( 'Custom Slug', 'canela' ),
				'description'	=> esc_html__('If you want your portfolio post type to have a custom slug in the url, please enter it here. You will still have to refresh your permalinks after saving this! This is done by going to Settings > Permalinks and clicking save.', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
		
		// View Project caption
		$wp_customize->add_setting(
			'clapat_canela_view_project_caption_first',
			array(
				'default'           	=> esc_html__( 'View', 'canela' ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_view_project_caption_first',
			array(
				'label'   		=> esc_html__( 'View Project Caption - First Line', 'canela' ),
				'description'	=> esc_html__( 'First line of the view caption displayed on hover in showcase or carousel templates.', 'canela' ),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_view_project_caption_second',
			array(
				'default'           	=> esc_html__( 'Project', 'canela' ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_view_project_caption_second',
			array(
				'label'   		=> esc_html__( 'View Project Caption - Second Line', 'canela' ),
				'description'	=> esc_html__( 'Second line of the view caption displayed on hover in showcase or carousel templates.', 'canela' ),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
		
		
		// Next Project caption
		$wp_customize->add_setting(
			'clapat_canela_portfolio_next_caption_first_line',
			array(
				'default'           	=> esc_html__('Next', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_next_caption_first_line',
			array(
				'label'   		=> esc_html__( 'Next Project Caption - First Line', 'canela' ),
				'description'	=> esc_html__('Caption of the next project in portfolio navigation displayed on hover - on two lines.', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_portfolio_next_caption_second_line',
			array(
				'default'           	=> esc_html__('Project', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_next_caption_second_line',
			array(
				'label'   		=> esc_html__( 'Next Project Caption - Second Line', 'canela' ),
				'description'	=> esc_html__('Caption of the next project in portfolio navigation displayed on hover - on two lines.', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
			
		// 'Quick Menu' portfolio items list caption
		$wp_customize->add_setting(
			'clapat_canela_portfolio_quick_menu_open_caption',
			array(
				'default'           	=> esc_html__('All Projects', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_quick_menu_open_caption',
			array(
				'label'   		=> esc_html__('Quick Menu Open Caption', 'canela'),
				'description'	=> esc_html__('The caption the quick menu button in the showcase slider that will open the portfolio items list.', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_portfolio_quick_menu_close_caption',
			array(
				'default'           	=> esc_html__('Close All', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_quick_menu_close_caption',
			array(
				'label'   		=> esc_html__('Quick Menu Close Caption', 'canela'),
				'description'	=> esc_html__('The caption the quick menu button in the showcase slider that will close the portfolio items list.', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
		
		// 'All' portfolio category caption
		$wp_customize->add_setting(
			'clapat_canela_portfolio_filter_all_caption',
			array(
				'default'           	=> esc_html__('All', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_filter_all_caption',
			array(
				'label'   		=> esc_html__('All Category Caption', 'canela'),
				'description'	=> esc_html__('The caption the All category displaying all portfolio items in portfolio page templates.', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
		
		// Portfolio Show Filters caption
		$wp_customize->add_setting(
			'clapat_canela_portfolio_show_filters_caption',
			array(
				'default'           	=> esc_html__('Show Filters', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_show_filters_caption',
			array(
				'label'   		=> esc_html__( 'Portfolio Grid - Show Filters Caption', 'canela' ),
				'description'	=> esc_html__('Caption of the Show Filters button displayed in Portfolio Grid layout.', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);
		
		// Portfolio Share Social Networks caption
		$wp_customize->add_setting(
			'clapat_canela_portfolio_share_social_networks_caption',
			array(
				'default'           		=> esc_html__('Share Project:', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_share_social_networks_caption',
			array(
				'label'   			=> esc_html__( 'Share This Project Caption', 'canela' ),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);	
		
		// Portfolio Share Social Networks list
		$wp_customize->add_setting(
			'clapat_canela_portfolio_share_social_networks',
			array(
				'default'           		=> '',
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_share_social_networks',
			array(
				'label'   		=> esc_html__( 'Share This Project On', 'canela' ),
				'description'	=> esc_html__('This is a list of social networks you can share the project on, displayed at the bottom right of the hero image. Leave this field empty if you do not want to show it. Type in the social lower case social networks names, separated by comma (,). The list of available networks: twitter, facebook, googleplus, linkedin, pinterest, email, stumbleupon, whatsapp, telegram, line, viber, pocket, messenger, vkontakte, rss', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'text',
			)
		);	
			
		// Portfolio navigation order
		$wp_customize->add_setting(
			'clapat_canela_portfolio_navigation_order',
			array(
				'default'           	=> 'forward',
				'sanitize_callback' 	=> 'canela_sanitize_portfolio_navigation_order',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_portfolio_navigation_order',
			array(
				'label'   		=> esc_html__('Portfolio Items Navigation Order', 'canela'),
				'section' 		=> 'portfolio_settings',
				'type'    		=> 'select',
				'choices'   	=> array( 'forward' => esc_html__('Forward in time (next item is newer or loops to the oldest if current item is the newest)', 'canela'),
											  'backward' => esc_html__('Backward in time (next item is older or loops to the newest if current item is the oldest)', 'canela') ),
			)
		);
		/*** End Portfolio Settings section ***/
		
		/*** Blog Settings section ***/
		$wp_customize->add_section(
			'blog_settings',
			array(
				'title'    => esc_html__( 'Blog Settings', 'canela' ),
				'priority' => ($canela_before_default_section - 3),
			)
		);
		
		// Navigation caption
		$wp_customize->add_setting(
			'clapat_canela_blog_next_post_caption',
			array(
				'default'           	=> esc_html__('Next', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_blog_next_post_caption',
			array(
				'label'   		=> esc_html__('Next Post Caption', 'canela'),
				'description'	=> esc_html__('Caption of the button linking to the next single blog post page.', 'canela'),
				'section' 		=> 'blog_settings',
				'type'    		=> 'text',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_blog_read_more_caption',
			array(
				'default'           	=> esc_html__('Read More', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_blog_read_more_caption',
			array(
				'label'   		=> esc_html__('Read More Caption', 'canela'),
				'description'	=> esc_html__('Caption of the button linking to the single blog post page from the blog index.', 'canela'),
				'section' 		=> 'blog_settings',
				'type'    		=> 'text',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_blog_prev_posts_caption',
			array(
				'default'           	=> esc_html__('Prev', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_blog_prev_posts_caption',
			array(
				'label'   		=> esc_html__('Previous Posts Page Caption', 'canela'),
				'description'	=> esc_html__('Caption of the button linking to the previous blog posts page.', 'canela'),
				'section' 		=> 'blog_settings',
				'type'    		=> 'text',
			)
		);
		
		$wp_customize->add_setting(
			'clapat_canela_blog_next_posts_caption',
			array(
				'default'           	=> esc_html__('Next', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_blog_next_posts_caption',
			array(
				'label'   		=> esc_html__('Next Posts Page Caption', 'canela'),
				'description'	=> esc_html__('Caption of the button linking to the next blog posts page.', 'canela'),
				'section' 		=> 'blog_settings',
				'type'    		=> 'text',
			)
		);
		
		// Blog pages default title
		$wp_customize->add_setting(
			'clapat_canela_blog_default_title',
			array(
				'default'           	=> esc_html__('Blog', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_blog_default_title',
			array(
				'label'   		=> esc_html__('Default Posts Page Title', 'canela'),
				'description'	=> esc_html__('Title of the default blog posts page. The default blog posts page is the page displaying blog posts when there is no front page set in Settings -> Reading.', 'canela'),
				'section' 		=> 'blog_settings',
				'type'    		=> 'text',
			)
		);
		/*** End Blog Settings section ***/
		
		/*** Map Settings section ***/
		$wp_customize->add_section(
			'map_settings',
			array(
				'title'    => esc_html__( 'Map Settings', 'canela' ),
				'priority' => ($canela_before_default_section - 2),
			)
		);
		
		// Map address
		$wp_customize->add_setting(
			'clapat_canela_map_address',
			array(
				'default'           	=>  esc_html__('775 New York Ave, Brooklyn, Kings, New York 11203', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_map_address',
			array(
				'label'   		=> esc_html__('Google Map Address', 'canela'),
				'description'  	=> esc_html__('Example: 775 New York Ave, Brooklyn, Kings, New York 11203. Or you can enter latitude and longitude for greater precision. Example: 41.40338, 2.17403 (in decimal degrees - DDD)', 'canela'),
				'section' 		=> 'map_settings',
				'type'    		=> 'text',
			)
		);
		
		// Map marker image
		$wp_customize->add_setting(
			'clapat_canela_map_marker',
			array(
				'default'           	=> get_template_directory_uri() . '/images/marker.png',
				'sanitize_callback' 	=> 'esc_url_raw',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Image_Control( 
			$wp_customize, 
			'clapat_canela_map_marker', 
			array(
				'label'      => esc_html__( 'Map Marker', 'canela' ),
				'description' => esc_html__('Please choose an image file for the marker.', 'canela'),
				'section'    => 'map_settings'
			)
		));
		
		// Map zoom
		$wp_customize->add_setting(
			'clapat_canela_map_zoom',
			array(
				'default'           	=> 16,
				'sanitize_callback' 	=> 'absint',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_map_zoom',
			array(
				'label'   		=> esc_html__( 'Map Zoom Level', 'canela' ),
				'description'  	=> esc_html__('Higher number will be more zoomed in.', 'canela'),
				'section' 		=> 'map_settings',
				'type'    		=> 'number',
				'input_attrs' 	=> array( 'min' => 0, 'max' => 30, 'step'  => 1 )
			)
		);
		
		// Pop-up marker title
		$wp_customize->add_setting(
			'clapat_canela_map_company_name',
			array(
				'default'           	=> esc_html__('Canela', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_map_company_name',
			array(
				'label'   		=> esc_html__('Pop-up marker title', 'canela'),
				'section' 		=> 'map_settings',
				'type'    		=> 'text',
			)
		);
		
		// Pop-up marker text
		$wp_customize->add_setting(
			'clapat_canela_map_company_info',
			array(
				'default'           	=> esc_html__('Here we are. Come to drink a coffee!', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_map_company_info',
			array(
				'label'   		=> esc_html__('Pop-up marker text', 'canela'),
				'section' 		=> 'map_settings',
				'type'    		=> 'text',
			)
		);
		
		// Map type
		$wp_customize->add_setting(
			'clapat_canela_map_type',
			array(
				'default'           	=> 'satellite',
				'sanitize_callback' 	=> 'canela_sanitize_map_type',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_map_type',
			array(
				'label'   		=> esc_html__('Map Type', 'canela'),
				'description'	=> esc_html__('Set the map type as road map or satellite.', 'canela'),
				'section' 		=> 'map_settings',
				'type'    		=> 'select',
				'choices'   	=> array( 'satellite' => esc_html__('Satellite', 'canela'),
										'roadmap' => esc_html__('Roadmap', 'canela') ),
			)
		);
		
		// Google maps API key
		$wp_customize->add_setting(
			'clapat_canela_map_api_key',
			array(
				'default'           	=> '',
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_map_api_key',
			array(
				'label'   		=> esc_html__('Google Maps API Key', 'canela'),
				'description'	=> esc_html__('Without it, the map may not be displayed. If you have an api key paste it here. More information on how to obtain a google maps api key: https://developers.google.com/maps/documentation/javascript/get-api-key#get-an-api-key', 'canela'),
				'section' 		=> 'map_settings',
				'type'    		=> 'text',
			)
		);
		/*** End Map Settings section ***/
		
		/*** Error Page section ***/
		$wp_customize->add_section(
			'error_page_settings',
			array(
				'title'    => esc_html__( 'Error Page Settings', 'canela' ),
				'priority' => ($canela_before_default_section - 1),
			)
		);
		
		// Error page title
		$wp_customize->add_setting(
			'clapat_canela_error_title',
			array(
				'default'           	=> esc_html__('404', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_error_title',
			array(
				'label'   		=> esc_html__('Error Page Title', 'canela'),
				'section' 		=> 'error_page_settings',
				'type'    		=> 'text',
			)
		);
		
		// Error page info
		$wp_customize->add_setting(
			'clapat_canela_error_info',
			array(
				'default'           	=> esc_html__('The page you are looking for could not be found.', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_error_info',
			array(
				'label'   		=> esc_html__('Error Page Info Text', 'canela'),
				'section' 		=> 'error_page_settings',
				'type'    		=> 'text',
			)
		);
		
		// Error back button
		$wp_customize->add_setting(
			'clapat_canela_error_back_button',
			array(
				'default'           	=> esc_html__('Home Page', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_error_back_button',
			array(
				'label'   		=> esc_html__('Back Button Caption', 'canela'),
				'section' 		=> 'error_page_settings',
				'type'    		=> 'text',
			)
		);
		
		// Error back button - caption on hover
		$wp_customize->add_setting(
			'clapat_canela_error_back_button_hover_caption',
			array(
				'default'           	=> esc_html__('Go Back', 'canela'),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_error_back_button_hover_caption',
			array(
				'label'   		=> esc_html__('Back Button Caption On Hover', 'canela'),
				'section' 		=> 'error_page_settings',
				'type'    		=> 'text',
			)
		);
		
		// Error back button url
		$wp_customize->add_setting(
			'clapat_canela_error_back_button_url',
			array(
				'default'           	=> esc_url( get_home_url() ),
				'sanitize_callback' 	=> 'canela_sanitize_text_field',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_error_back_button_url',
			array(
				'label'   		=> esc_html__('Back Button URL', 'canela'),
				'section' 		=> 'error_page_settings',
				'type'    		=> 'text',
			)
		);
		
		// 404 page background type
		$wp_customize->add_setting(
			'clapat_canela_error_page_bknd_type',
			array(
				'default'           	=> 'light-content',
				'sanitize_callback' 	=> 'canela_sanitize_error_page_bknd_type',
			)
		);
		
		$wp_customize->add_control(
			'clapat_canela_error_page_bknd_type',
			array(
				'label'   		=> esc_html__('Background Type', 'canela'),
				'description'	=> esc_html__('Background type for the 404 error page.', 'canela'),
				'section' 		=> 'error_page_settings',
				'type'    		=> 'select',
				'choices'   	=> array( 'dark-content' 	=> esc_html__('White', 'canela'),
										'light-content' => esc_html__('Black', 'canela') ),
			)
		);
		/*** End Error Page Settings section ***/
	}

	add_action( 'customize_register', 'canela_options_config' );
}

/**
 * Sanitize a text or textarea field
 *
 * @param string $input - the text
 */
function canela_sanitize_text_field( $input ) {
	
	return wp_kses( $input, 'canela_allowed_html' );
}

/**
 * Sanitize a custom slug field
 *
 * @param string $input - the input slug
 */
function canela_sanitize_slug_field( $input ) {
	
	return sanitize_title( $input );
}


/**
 * Sanitize the social network options.
 *
 * @param string $input social network id.
 */
function canela_sanitize_social_links( $input ) {
	
	global $canela_social_links;
	$valid = array_keys( $canela_social_links );
	
	if ( in_array( $input, $valid, true ) ) {
		return $input;
	}

	return 'Fb';
}


/**
 * Sanitize the portfolio navigation order.
 *
 * @param string $input - portfolio navigation order
 */
function canela_sanitize_portfolio_navigation_order( $input ) {
	
	$valid = array( 'forward', 'backward' );
	
	if ( in_array( $input, $valid, true ) ) {
		return $input;
	}

	return 'forward';
}

/**
 * Sanitize the showcase transition pattern settings.
 *
 * @param string $input - showcase transition
 */
function canela_sanitize_showcase_transition_pattern_image( $input ) {
	
	global $canela_slide_transitions;
	$valid = array_keys( $canela_slide_transitions );
	
	if ( in_array( $input, $valid, true ) ) {
		return $input;
	}

	return 'first';
}

/**
 * Sanitize the map type
 *
 * @param string $input - map type
 */
function canela_sanitize_map_type( $input ) {
	
	$valid = array( 'satellite', 'roadmap' );
	
	if ( in_array( $input, $valid, true ) ) {
		return $input;
	}

	return 'satellite';
}

/**
 * Sanitize the global page background type
 *
 * @param string $input - background type
 */
function canela_sanitize_default_page_bknd_type( $input ) {
	
	$valid = array( 'dark-content', 'light-content' );
	
	if ( in_array( $input, $valid, true ) ) {
		return $input;
	}

	return 'light-content';
}

/**
 * Sanitize the error page background type
 *
 * @param string $input - background type
 */
function canela_sanitize_error_page_bknd_type( $input ) {
	
	$valid = array( 'dark-content', 'light-content' );
	
	if ( in_array( $input, $valid, true ) ) {
		return $input;
	}

	return 'light-content';
}